# File: OregonEstuaries.R
# Purpose: Example area GRTS survey design for estuaries within Oregon
# Programmers: Tony Olsen and Tom Kincaid
# Date: May 5, 2005
# Last Modified: October 13, 2006

# Load the spsurvey library

library(spsurvey)

# Read the attribute table from the shapefile

att <- read.dbf('Oregon2001Estuaries')
cat("The initial six lines in the attribute data frame follow:\n\n")
print(head(att))

# Change the calculated area of estuary polygons to sq km from sq meters

att$area_mdm <- att$area_mdm/1000/1000

# Summarize the NCA size classes

cat("\nA summary of the NSA size classes follows:\n\n")
print(summary(att$CLASS))

# Create an estuary size variable

att$EstSize <- cut(att$SQ_KILOMET, breaks=c(0, 1, 25,50), include.lowest=TRUE,
                   labels=c("Small", "Medium", "Large"))

# Create the design list

dsgn <- list("< 100 SQ.Kilometers"=list(panel=c(PanelOne=25, PanelTwo=25),
             seltype="Unequal", caty.n=c(Small=17, Medium=17, Large=16),
             over=50))

# Call the grts function, which will require approximately 60 minutes to execute

cat("\nThe following information is printed by \"grts\" while it is executing:\n")
sites <- grts(design=dsgn, 
              DesignID="OREstEQ", 
              type.frame="area",
              src.frame="shapefile",
              in.shape="Oregon2001Estuaries",
              att.frame=att,
              mdcaty="EstSize",  
              shapefile=TRUE, 
              prjfilename="Oregon2001Estuaries", 
              out.shape="OREstuary.UnEqualSites")

# Print the initial six lines of the survey design

cat("\nThe initial six lines of the survey design follow:\n\n")
print(head(sites@data))
cat("\n")

# Print the survey design summary

cat("\nThe survey design summary follows:\n\n")
print(dsgnsum(sites))
